%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Analisi dinamica d'un aerogenerador connectat%
% directament a la xarxa (maquina d' induccio) %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all ;     % Neteja el workspace
close all ;     % Tanca tot es les figures
clc ;           % Neteja el command window

%% Durada de la simulacio
Tsimul=15;

%% Parametres del vent
vw=11;          % Velocitat del vent
rho=1.225;      % Densidad del aire

%% Parametres electrics nominals de la maquina
Pnom=2e6 ;      % Potencia nominal de la maquina
fase_ini=90;    % Fase inicial []
Vnom=960;       % Tensio nominal de la maquina

Theta_grid_0=0; % Angulo de la red inicial [] (importante para las condiciones iniciales de los PLL!!) 


%% Banco condensadores (estrella)
Qc=-1i*500e3;   % Potencia reactiva a compensar [VAr]
t_switch=11.5;  % Tiempo de conexin banco de condensadores [s]

%% Parametres TURBINA
%Parametres Cp [ Taula de valors de Cp]
% Variable speed
c1=.73; c2=151; c3=0.58; c4=.002; c5=2.14; c6=13.2; c7=18.4; c8=-.02; c9=-.003;
Pitch=0;


% Datos turbina
Cut_in=3;           % Cut-in speed [m/s]
Cut_off=20;         % Cut-off speed [m/s]
wt=16;              % Velocidad de las palas [rpm]
Jt=9.0e6;           % Momento de inercia [kgm2]
N=83;               % Gearbox ratio for SCIG [-]
D=76;               % Diametro de pala [m]

% Generador SCIG
Pn=2;               % Potencia nominal [MW]
f=50;               % Frecuencia nominal [Hz]
Unom=960;           % Voltaje (phase?phase RMS) [V]
Inom=1300;          % Intensidad de red [A]
p=2;                % Pares de polos [-]
Jg=90;              % Inercia del motor [kgm2]

% Parametros Electricos
Rs=5e-3;            % Nominal Stator resistance [?] 
Lsd=4e-4;           % Stator leakage inductance [H]
Rr=9e-3;            % Rotor resistance [?]
Lrd=3e-4;           % Rotor leakage inductance [H]
Lm=15e-3;           % Magnetizing inductance [H]
Rfe=140;            % Iron loss resistance [?]

%%  CALCULOS PRELIMINARES
ws=2*pi*f/p;        % velocidad de sincronismo [rpm]
w=2*pi*f;           % Pulsacion elctrica [rad/s]

Ls=Lsd+Lm;              % Stator inductance [H]
Lr=Lrd+Lm;              % Rotor inductance [H]
sigma=1-Lm^2/(Ls*Lr);   % Machine Leakage inductance [H]

Xsd=1i*w*Lsd;       % Reactancia del estator [ohm]
Xrd=1i*w*Lrd;       % Reactancia del rotor [ohm]
Xm=1i*w*Lm;         % Reactancia del magnetizacion [ohm]

Area=pi*D^2/4;      % Area barrida por las palas [m2]

% Condensadores (estrella)
Ic=conj(Qc/(sqrt(3)*Vnom)); 
Zc=(Vnom/sqrt(3))/Ic;
C=1/(1i*w*Zc);      % Capacidad de los condensadores [F]


%% Parametros de los elementos de la simulacin.

% Filtro de red
Ll=5.4e-3;      % Inductancia del filtro de red [H]
rl=.5;          % Resistencia del filtro de red [ohm]

% Filtro de rotor
Lf=5.4e-3;      % Inductancia del filtro de red [H]
rf=.5;          % Resistencia del filtro de red [ohm]

% Control DC
Cbus=3e-3;                      % Capacidad del condensador del bus DC [F]
MpDC=.05;                       % Sobreimpulso de la respuesta deseada [-]
tsDC=0.01;                      % Tiempo de establecimiento seal DC al 5% [s]
XiDC=sqrt(1/(1+(pi/log(MpDC))^2));  % Factor amortiguamiento control DC [-]
wnDC=3/(XiDC*tsDC);             % Frecuencia natural control DC [rad/s]
%XiDC=0.707;
%wnDC=418.88;

KpDC=Cbus*XiDC*wnDC;            % Constante proporcional PI de DC [-]
KiDC=wnDC^2*Cbus/2;             % Constante integradora PI de DC [-]

uzq=(400*sqrt(2/3));
m=uzq/800;
KpDC_mem=4*Cbus/(3*m)*XiDC*wnDC;    % Constante proporcional PI de DC [-]
KiDC_mem=2*Cbus/(3*m)*wnDC^2;       % Constante integradora PI de DC [-]

% Control lazos corriente GSC
Tau_igsc=1e-3;                  % Constante de tiempo electrica [s]
Kp_igsc=Ll/Tau_igsc;            % Constante proporcional PI de i_GSC [-]
Ki_igsc=rl/Tau_igsc;            % Constante integradora PI de i_GSC [-]

% Control lazos corriente RSC
Tau_igsc=1e-2;                  % Constante de tiempo electrica [s]
Kp_irsc=Lr/Tau_igsc;            % Constante proporcional PI de i_RSC [-]
Ki_irsc=Rr/Tau_igsc;            % Constante integradora PI de i_RSC [-]

% Referencias DTC
k1=sigma*Lr/Lm+Lm/Ls;
k2=-sigma*Lr*Ls/(3/2*100*pi*Lm);
k3=-sigma*Lr*Ls/(3/2*p*Lm);